@@ -1,4 +1,4 @@
-use schemars::{gen::SchemaGenerator, schema::Schema, JsonSchema};
+use schemars::{JsonSchema, Schema, SchemaGenerator};
 use serde::{de, ser, Deserialize, Serialize};
 use std::borrow::Cow;
 
@@ -70,8 +70,8 @@ impl<'de, T: Deserialize<'de>> Deserialize<'de> for Maybe<T> {
 }
 
 impl<T: JsonSchema> JsonSchema for Maybe<T> {
-  fn schema_name() -> String {
-    format!("Maybe_{}", T::schema_name())
+  fn schema_name() -> Cow<'static, str> {
+    Cow::Owned(format!("Maybe_{}", T::schema_name()))
   }
   fn schema_id() -> Cow<'static, str> {
     Cow::Owned(format!("Maybe<{}>", T::schema_id()))
@@ -80,6 +80,10 @@ impl<T: JsonSchema> JsonSchema for Maybe<T> {
     gen.subschema_for::<T>()
   }
 
+  fn inline_schema() -> bool {
+    true
+  }
+
   fn _schemars_private_non_optional_json_schema(gen: &mut SchemaGenerator) -> Schema {
     T::_schemars_private_non_optional_json_schema(gen)
   }
