@@ -1,6 +1,4 @@
 #![cfg(test)]
-use ast_grep_core::source::TSParseError;
-
 use super::*;
 
 fn test_match(query: &str, source: &str) {
@@ -15,18 +13,17 @@ fn test_css_pattern() {
   test_match(".a { $PROP: red; }", ".a { color: red; }");
 }
 
-fn test_replace(src: &str, pattern: &str, replacer: &str) -> Result<String, TSParseError> {
+fn test_replace(src: &str, pattern: &str, replacer: &str) -> String {
   use crate::test::test_replace_lang;
   test_replace_lang(src, pattern, replacer, Css)
 }
 
 #[test]
-fn test_css_replace() -> Result<(), TSParseError> {
+fn test_css_replace() {
   let ret = test_replace(
     ".a {color: red; }",
     ".a { color: $COLOR}",
     ".a {background: $COLOR}",
-  )?;
+  );
   assert_eq!(ret, ".a {background: red}");
-  Ok(())
 }
