@@ -1,6 +1,4 @@
 #![cfg(test)]
-use ast_grep_core::source::TSParseError;
-
 use super::*;
 
 fn test_match(query: &str, source: &str) {
@@ -33,13 +31,13 @@ func plus(a int, b int) int {
   );
 }
 
-fn test_replace(src: &str, pattern: &str, replacer: &str) -> Result<String, TSParseError> {
+fn test_replace(src: &str, pattern: &str, replacer: &str) -> String {
   use crate::test::test_replace_lang;
   test_replace_lang(src, pattern, replacer, Go)
 }
 
 #[test]
-fn test_go_replace() -> Result<(), TSParseError> {
+fn test_go_replace() {
   let ret = test_replace(
     r#"
 func intSeq() {
@@ -50,7 +48,7 @@ func intSeq() {
     r#"defer func() {
 $$$BODY }()"#,
     r#"func b() { $$$BODY }"#,
-  )?;
+  );
   assert_eq!(
     ret,
     r#"
@@ -58,5 +56,4 @@ func intSeq() {
   func b() { i++ }
 }"#
   );
-  Ok(())
 }
